[PATCH 01/17] futex: Cleanup variable names for futex_top_waiter()

2018-11-09 Thread Henrik Austad
From: Peter Zijlstra 

commit 499f5aca2cdd5e958b27e2655e7e7f82524f46b1 uptream.

futex_top_waiter() returns the top-waiter on the pi_mutex. Assinging
this to a variable 'match' totally obscures the code.

Signed-off-by: Peter Zijlstra (Intel) 
Cc: juri.le...@arm.com
Cc: bige...@linutronix.de
Cc: xlp...@redhat.com
Cc: rost...@goodmis.org
Cc: mathieu.desnoy...@efficios.com
Cc: jdesfos...@efficios.com
Cc: dvh...@infradead.org
Cc: bris...@redhat.com
Link: http://lkml.kernel.org/r/20170322104151.554710...@infradead.org
Signed-off-by: Thomas Gleixner 
Tested-by: Henrik Austad 
---
 kernel/futex.c | 30 +++---
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/kernel/futex.c b/kernel/futex.c
index a26d217..bb87324 100644
--- a/kernel/futex.c
+++ b/kernel/futex.c
@@ -1116,14 +1116,14 @@ static int attach_to_pi_owner(u32 uval, union futex_key 
*key,
 static int lookup_pi_state(u32 uval, struct futex_hash_bucket *hb,
   union futex_key *key, struct futex_pi_state **ps)
 {
-   struct futex_q *match = futex_top_waiter(hb, key);
+   struct futex_q *top_waiter = futex_top_waiter(hb, key);
 
/*
 * If there is a waiter on that futex, validate it and
 * attach to the pi_state when the validation succeeds.
 */
-   if (match)
-   return attach_to_pi_state(uval, match->pi_state, ps);
+   if (top_waiter)
+   return attach_to_pi_state(uval, top_waiter->pi_state, ps);
 
/*
 * We are the first waiter - try to look up the owner based on
@@ -1170,7 +1170,7 @@ static int futex_lock_pi_atomic(u32 __user *uaddr, struct 
futex_hash_bucket *hb,
struct task_struct *task, int set_waiters)
 {
u32 uval, newval, vpid = task_pid_vnr(task);
-   struct futex_q *match;
+   struct futex_q *top_waiter;
int ret;
 
/*
@@ -1196,9 +1196,9 @@ static int futex_lock_pi_atomic(u32 __user *uaddr, struct 
futex_hash_bucket *hb,
 * Lookup existing state first. If it exists, try to attach to
 * its pi_state.
 */
-   match = futex_top_waiter(hb, key);
-   if (match)
-   return attach_to_pi_state(uval, match->pi_state, ps);
+   top_waiter = futex_top_waiter(hb, key);
+   if (top_waiter)
+   return attach_to_pi_state(uval, top_waiter->pi_state, ps);
 
/*
 * No waiter and user TID is 0. We are here because the
@@ -1288,11 +1288,11 @@ static void mark_wake_futex(struct wake_q_head *wake_q, 
struct futex_q *q)
q->lock_ptr = NULL;
 }
 
-static int wake_futex_pi(u32 __user *uaddr, u32 uval, struct futex_q *this,
+static int wake_futex_pi(u32 __user *uaddr, u32 uval, struct futex_q 
*top_waiter,
 struct futex_hash_bucket *hb)
 {
struct task_struct *new_owner;
-   struct futex_pi_state *pi_state = this->pi_state;
+   struct futex_pi_state *pi_state = top_waiter->pi_state;
u32 uninitialized_var(curval), newval;
WAKE_Q(wake_q);
bool deboost;
@@ -1313,11 +1313,11 @@ static int wake_futex_pi(u32 __user *uaddr, u32 uval, 
struct futex_q *this,
 
/*
 * It is possible that the next waiter (the one that brought
 * this owner to the kernel) timed out and is no longer
 * waiting on the lock.
 */
if (!new_owner)
-   new_owner = this->task;
+   new_owner = top_waiter->task;
 
/*
 * We pass it to the next owner. The WAITERS bit is always
@@ -2639,7 +2639,7 @@ static int futex_unlock_pi(u32 __user *uaddr, unsigned 
int flags)
u32 uninitialized_var(curval), uval, vpid = task_pid_vnr(current);
union futex_key key = FUTEX_KEY_INIT;
struct futex_hash_bucket *hb;
-   struct futex_q *match;
+   struct futex_q *top_waiter;
int ret;
 
 retry:
@@ -2663,9 +2663,9 @@ retry:
 * all and we at least want to know if user space fiddled
 * with the futex value instead of blindly unlocking.
 */
-   match = futex_top_waiter(hb, );
-   if (match) {
-   ret = wake_futex_pi(uaddr, uval, match, hb);
+   top_waiter = futex_top_waiter(hb, );
+   if (top_waiter) {
+   ret = wake_futex_pi(uaddr, uval, top_waiter, hb);
/*
 * In case of success wake_futex_pi dropped the hash
 * bucket lock.
@@ -1313,11 +1313,11 @@ static int wake_futex_pi(u32 __user *uaddr, u32 uval, 
/*
 * It is possible that the next waiter (the one that brought
-* this owner to the kernel) timed out and is no longer
+* top_waiter owner to the kernel) timed out and is no longer
 * waiting on the lock.
 */
-- 
2.7.4



[PATCH 01/17] futex: Cleanup variable names for futex_top_waiter()

2018-11-09 Thread Henrik Austad
From: Peter Zijlstra 

commit 499f5aca2cdd5e958b27e2655e7e7f82524f46b1 uptream.

futex_top_waiter() returns the top-waiter on the pi_mutex. Assinging
this to a variable 'match' totally obscures the code.

Signed-off-by: Peter Zijlstra (Intel) 
Cc: juri.le...@arm.com
Cc: bige...@linutronix.de
Cc: xlp...@redhat.com
Cc: rost...@goodmis.org
Cc: mathieu.desnoy...@efficios.com
Cc: jdesfos...@efficios.com
Cc: dvh...@infradead.org
Cc: bris...@redhat.com
Link: http://lkml.kernel.org/r/20170322104151.554710...@infradead.org
Signed-off-by: Thomas Gleixner 
Tested-by: Henrik Austad 
---
 kernel/futex.c | 30 +++---
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/kernel/futex.c b/kernel/futex.c
index a26d217..bb87324 100644
--- a/kernel/futex.c
+++ b/kernel/futex.c
@@ -1116,14 +1116,14 @@ static int attach_to_pi_owner(u32 uval, union futex_key 
*key,
 static int lookup_pi_state(u32 uval, struct futex_hash_bucket *hb,
   union futex_key *key, struct futex_pi_state **ps)
 {
-   struct futex_q *match = futex_top_waiter(hb, key);
+   struct futex_q *top_waiter = futex_top_waiter(hb, key);
 
/*
 * If there is a waiter on that futex, validate it and
 * attach to the pi_state when the validation succeeds.
 */
-   if (match)
-   return attach_to_pi_state(uval, match->pi_state, ps);
+   if (top_waiter)
+   return attach_to_pi_state(uval, top_waiter->pi_state, ps);
 
/*
 * We are the first waiter - try to look up the owner based on
@@ -1170,7 +1170,7 @@ static int futex_lock_pi_atomic(u32 __user *uaddr, struct 
futex_hash_bucket *hb,
struct task_struct *task, int set_waiters)
 {
u32 uval, newval, vpid = task_pid_vnr(task);
-   struct futex_q *match;
+   struct futex_q *top_waiter;
int ret;
 
/*
@@ -1196,9 +1196,9 @@ static int futex_lock_pi_atomic(u32 __user *uaddr, struct 
futex_hash_bucket *hb,
 * Lookup existing state first. If it exists, try to attach to
 * its pi_state.
 */
-   match = futex_top_waiter(hb, key);
-   if (match)
-   return attach_to_pi_state(uval, match->pi_state, ps);
+   top_waiter = futex_top_waiter(hb, key);
+   if (top_waiter)
+   return attach_to_pi_state(uval, top_waiter->pi_state, ps);
 
/*
 * No waiter and user TID is 0. We are here because the
@@ -1288,11 +1288,11 @@ static void mark_wake_futex(struct wake_q_head *wake_q, 
struct futex_q *q)
q->lock_ptr = NULL;
 }
 
-static int wake_futex_pi(u32 __user *uaddr, u32 uval, struct futex_q *this,
+static int wake_futex_pi(u32 __user *uaddr, u32 uval, struct futex_q 
*top_waiter,
 struct futex_hash_bucket *hb)
 {
struct task_struct *new_owner;
-   struct futex_pi_state *pi_state = this->pi_state;
+   struct futex_pi_state *pi_state = top_waiter->pi_state;
u32 uninitialized_var(curval), newval;
WAKE_Q(wake_q);
bool deboost;
@@ -1313,11 +1313,11 @@ static int wake_futex_pi(u32 __user *uaddr, u32 uval, 
struct futex_q *this,
 
/*
 * It is possible that the next waiter (the one that brought
 * this owner to the kernel) timed out and is no longer
 * waiting on the lock.
 */
if (!new_owner)
-   new_owner = this->task;
+   new_owner = top_waiter->task;
 
/*
 * We pass it to the next owner. The WAITERS bit is always
@@ -2639,7 +2639,7 @@ static int futex_unlock_pi(u32 __user *uaddr, unsigned 
int flags)
u32 uninitialized_var(curval), uval, vpid = task_pid_vnr(current);
union futex_key key = FUTEX_KEY_INIT;
struct futex_hash_bucket *hb;
-   struct futex_q *match;
+   struct futex_q *top_waiter;
int ret;
 
 retry:
@@ -2663,9 +2663,9 @@ retry:
 * all and we at least want to know if user space fiddled
 * with the futex value instead of blindly unlocking.
 */
-   match = futex_top_waiter(hb, );
-   if (match) {
-   ret = wake_futex_pi(uaddr, uval, match, hb);
+   top_waiter = futex_top_waiter(hb, );
+   if (top_waiter) {
+   ret = wake_futex_pi(uaddr, uval, top_waiter, hb);
/*
 * In case of success wake_futex_pi dropped the hash
 * bucket lock.
@@ -1313,11 +1313,11 @@ static int wake_futex_pi(u32 __user *uaddr, u32 uval, 
/*
 * It is possible that the next waiter (the one that brought
-* this owner to the kernel) timed out and is no longer
+* top_waiter owner to the kernel) timed out and is no longer
 * waiting on the lock.
 */
-- 
2.7.4